@@ -1,6 +1,6 @@
 /*
     zgetopt.c - getopt compatibility layer
-    Copyright (C) 2011 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2018 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -35,7 +35,14 @@ int getopt(int argc, char *argv[], char *optstring){
 		return '?';
 	}
 	optarg += 2;
-	if (*optarg == '\0') optarg = NULL;
+	if (*optarg == '\0') {
+		if (cc[1] == ':'){
+			optind++;
+	        optarg = argv[optind];
+		}else{
+			optarg = NULL;
+		}
+	}
 	
 	optind++;
 	return c;
